@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1103';
+our $VERSION = '0.1104';
 
 use Moo;
 use strictures 2;
@@ -301,6 +301,7 @@ sub populate {
 
                     # Add each chosen note to the score
                     for my $note ( split /\s+/, $choice ) {
+                        # XXX This is not sophisticated at all
                         my $duration = $self->durations->[ int rand @{ $self->durations } ];
                         $self->score->n( $duration, $note );
                     }
@@ -356,6 +357,7 @@ sub populate {
                         $self->score->r( $self->pause_duration );
                     }
                     else {
+                        # XXX This is not sophisticated at all
                         my $duration = $self->durations->[ int rand @{ $self->durations } ];
                         $self->score->n( $duration, $note );
                     }
@@ -432,12 +434,13 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1103
+version 0.1104
 
 =head1 SYNOPSIS
 
   use MIDI::Ngram;
 
+  # Analyze a tune and build a new MIDI file of repetitions
   my $mng = MIDI::Ngram->new(
     in_file      => [ 'eg/twinkle_twinkle.mid' ],
     ngram_size   => 3,
@@ -447,13 +450,31 @@ version 0.1103
   );
 
   my $analysis = $mng->process;
-
-  print Dumper $mng->net;
+  print $analysis;
 
   my $playback = $mng->populate;
 
   $mng->write;
 
+  # Analyze multitrack tunes
+  $mng = MIDI::Ngram->new(
+    in_file     => [ '/multi/channel/tune1.mid', '/multi/channel/tune2.mid' ],
+    ngram_size  => 3,
+    one_channel => 1,
+  );
+
+  $mng->process;
+
+  # Dump out the phrases in order
+  print Dumper [
+    map { "$_ => " . $mng->notes->{0}{$_} }
+      sort { $mng->notes->{0}{$a} <=> $mng->notes->{0}{$b} }
+        keys %{ $mng->notes->{0} }
+  ];
+
+  # Inspect the phrase transition network
+  print Dumper $mng->net;
+
 =head1 DESCRIPTION
 
 C<MIDI::Ngram> parses a given list of MIDI files, finds the top
@@ -524,8 +545,8 @@ Default: C<10>
 =head2 weight
 
 Boolean.  Play phrases according to the probability of their
-repetition occurrence with the
-L<List::Util::WeightedChoice/choose_weighted> function.
+repetition occurrence with the function
+L<List::Util::WeightedChoice/choose_weighted>.
 
 Default: C<0>
 
